---
title: <span class="badge object-type-scalar"></span> WritesPerSecond
---
# <span class="badge object-type-scalar"></span> WritesPerSecond

Throughput: writes/sec (wps)

## Definition

```python
# Throughput: writes/sec (wps)
WritesPerSecond: typing.Literal["wps"] = "wps"
```
